@@ -3,7 +3,7 @@ import sys,click
 @click.command()
 @click.option('-x', '--xmindpath', 'xmindpath', required=True, help='xmind file path')
 @click.option('-e', '--excelpath', 'excelpath', required=True, help='excel file path')
-@click.option('-i', '--ignorelayer', 'ignorelayer', is_flag=True, default='0')
+@click.option('-i', '--ignorelayer', 'ignorelayer', required=True)
 def test(xmindpath, excelpath, ignorelayer):
     print(xmindpath + 'haha' + excelpath + 'haha' + ignorelayer)
     # if ignorelayer == '0':
